@@ -5,7 +5,8 @@
 #' defined by `r rfc(6749, 4.3)`. It allows the user to supply their password
 #' once, exchanging it for an access token that can be cached locally.
 #'
-#' Learn more about the overall OAuth authentication flow in `vignette("oauth")`.
+#' Learn more about the overall OAuth authentication flow in
+#' <https://httr2.r-lib.org/articles/oauth.html>
 #'
 #' @export
 #' @family OAuth flows
@@ -24,15 +25,16 @@
 #'   request("https://example.com") |>
 #'     req_auth()
 #' }
-req_oauth_password <- function(req,
-                               client,
-                               username,
-                               password = NULL,
-                               scope = NULL,
-                               token_params = list(),
-                               cache_disk = FALSE,
-                               cache_key = username) {
-
+req_oauth_password <- function(
+  req,
+  client,
+  username,
+  password = NULL,
+  scope = NULL,
+  token_params = list(),
+  cache_disk = FALSE,
+  cache_key = username
+) {
   params <- list(
     client = client,
     username = username,
@@ -46,17 +48,22 @@ req_oauth_password <- function(req,
 
 #' @export
 #' @rdname req_oauth_password
-oauth_flow_password <- function(client,
-                                username,
-                                password = NULL,
-                                scope = NULL,
-                                token_params = list()) {
-  oauth_flow_check("resource owner password credentials", client,
+oauth_flow_password <- function(
+  client,
+  username,
+  password = NULL,
+  scope = NULL,
+  token_params = list()
+) {
+  oauth_flow_check(
+    "resource owner password credentials",
+    client,
     interactive = is.null(password)
   )
   check_string(username)
 
-  oauth_client_get_token(client,
+  oauth_client_get_token(
+    client,
     grant_type = "password",
     username = username,
     password = check_password(password),
