@@ -26,8 +26,8 @@ test_that("can parse media type", {
 test_that("can parse authenticate header", {
   header <- paste0(
     'Bearer realm="example",',
-    'error="invalid_token",','
-    error_description="The access token expired"'
+    'error="invalid_token",',
+    'error_description="The access token expired"'
   )
   out <- parse_www_authenticate(header)
   expect_equal(out$scheme, "Bearer")
@@ -85,6 +85,6 @@ test_that("parse_name_equals_value handles empty values", {
 test_that("parse_match converts missing matches to NULL", {
   expect_equal(
     parse_match("abbbd", "(a)(b+)(c*)(d)"),
-    list("a", "bbb", NULL, "d"
-  ))
+    list("a", "bbb", NULL, "d")
+  )
 })
