@@ -1,3 +1,10 @@
+test_that("has useful default (with message)", {
+  req <- request_test()
+  expect_snapshot(req <- req_retry(req))
+  expect_equal(retry_max_tries(req), 2)
+  expect_equal(retry_max_seconds(req), Inf)
+})
+
 test_that("can set define maximum retries", {
   req <- request_test()
   expect_equal(retry_max_tries(req), 1)
@@ -21,7 +28,11 @@ test_that("can override default is_transient", {
   expect_equal(retry_is_transient(req, response(404)), FALSE)
   expect_equal(retry_is_transient(req, response(429)), TRUE)
 
-  req <- req_retry(req, is_transient = ~ resp_status(.x) == 404)
+  req <- req_retry(
+    req,
+    max_tries = 2,
+    is_transient = \(resp) resp_status(resp) == 404
+  )
   expect_equal(retry_is_transient(req, response(404)), TRUE)
   expect_equal(retry_is_transient(req, response(429)), FALSE)
 })
@@ -34,7 +45,7 @@ test_that("can override default backoff", {
   expect_equal(retry_backoff(req, 5), 26.9)
   expect_equal(retry_backoff(req, 10), 60)
 
-  req <- req_retry(req, backoff = ~ 10)
+  req <- req_retry(req, max_tries = 2, backoff = \(i) 10)
   expect_equal(retry_backoff(req, 1), 10)
   expect_equal(retry_backoff(req, 5), 10)
   expect_equal(retry_backoff(req, 10), 10)
@@ -45,27 +56,42 @@ test_that("can override default retry wait", {
   req <- request_test()
   expect_equal(retry_after(req, resp, 1), 10)
 
-  req <- req_retry(req, after = ~ as.numeric(resp_header(.x, "Wait-For")))
+  req <- req_retry(
+    req,
+    max_tries = 2,
+    after = \(resp) as.numeric(resp_header(resp, "Wait-For"))
+  )
   expect_equal(retry_after(req, resp, 1), 20)
 })
 
 test_that("missing retry-after uses backoff", {
   req <- request_test()
-  req <- req_retry(req, backoff = ~ 10)
+  req <- req_retry(req, max_tries = 2, backoff = \(i) 10)
 
   expect_equal(retry_after(req, response(429), 1), 10)
 })
 
 test_that("useful message if `after` wrong", {
-  req <- request_test() %>%
+  req <- request_test() |>
     req_retry(
       is_transient = function(resp) TRUE,
-      after = function(resp) resp
+      after = function(resp) resp,
+      max_tries = 2
     )
 
   expect_snapshot(req_perform(req), error = TRUE)
 })
 
+test_that("validates its inputs", {
+  req <- new_request("http://example.com")
+
+  expect_snapshot(error = TRUE, {
+    req_retry(req, max_tries = 0)
+    req_retry(req, max_tries = 2, max_seconds = "x")
+    req_retry(req, max_tries = 2, retry_on_failure = "x")
+  })
+})
+
 test_that("is_number_or_na implemented correctly", {
   expect_equal(is_number_or_na(1), TRUE)
   expect_equal(is_number_or_na(NA_real_), TRUE)
@@ -75,3 +101,33 @@ test_that("is_number_or_na implemented correctly", {
   expect_equal(is_number_or_na(numeric()), FALSE)
   expect_equal(is_number_or_na("x"), FALSE)
 })
+
+
+# circuit breaker --------------------------------------------------------
+
+test_that("triggered after specified requests", {
+  req <- request_test("/status/:status", status = 429) |>
+    req_retry(
+      after = function(resp) 0,
+      max_tries = 10,
+      failure_threshold = 1
+    )
+
+  # First attempt performs, retries, then errors
+  req_perform(req) |>
+    expect_condition(class = "httr2_perform") |>
+    expect_condition(class = "httr2_retry") |>
+    expect_error(class = "httr2_breaker")
+
+  # Second attempt errors without performing
+  req_perform(req) |>
+    expect_no_condition(class = "httr2_perform") |>
+    expect_error(class = "httr2_breaker")
+
+  # Attempt on same realm errors without trying at all
+  req2 <- request_test("/status/:status", status = 200) |>
+    req_retry(max_tries = 2)
+  req_perform(req) |>
+    expect_no_condition(class = "httr2_perform") |>
+    expect_error(class = "httr2_breaker")
+})
